===============================
EveResource
===============================


.. image:: https://img.shields.io/pypi/v/eve_resource.svg
        :target: https://pypi.python.org/pypi/eve_resource

.. image:: https://img.shields.io/travis/m-housh/eve_resource.svg
        :target: https://travis-ci.org/m-housh/eve_resource

.. image:: https://coveralls.io/repos/github/m-housh/eve_resource/badge.svg?branch=master
        :target: https://coveralls.io/github/m-housh/eve_resource?branch=master

         
.. image:: https://readthedocs.org/projects/eve-resource/badge/?version=latest
        :target: https://eve-resource.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Resource utilities for Eve


* Free software: MIT license
* Documentation: https://eve-resource.readthedocs.io.


Features
--------

* Resource level utilities for Eve api's 

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

